@@ -44,7 +44,7 @@ sub new {
 	my $self = {};
 	bless $self, $type;
 
-	$self->version("0.5");
+	$self->version("1");
 	$self->algorithm($prms{'Algorithm'} || "rsa-sha1");
 	$self->signature($prms{'Signature'});
 	$self->canonicalization($prms{'Method'} || "simple");
@@ -95,10 +95,10 @@ sub parse
 	my $self = $class->SUPER::parse($string);
 	$self->{prefix} = $prefix;
 
-	# TODO: check version
+	# check version
 	if (my $version = $self->version)
 	{
-		my @ALLOWED_VERSIONS = ("0.5");
+		my @ALLOWED_VERSIONS = ("0.5", "1");
 		unless (grep {$_ eq $version} @ALLOWED_VERSIONS)
 		{
 			die "unsupported v=$version tag\n";
@@ -374,9 +374,9 @@ sub check_protocol
 	return if ($options && $options ne "txt");
 
 	my $v = $self->version;
-	if ($v && $v eq "0.5")
+	if ($v)
 	{
-		# in v=0.5 signatures, the /txt option is REQUIRED
+		# in v=1 signatures, the /txt option is REQUIRED
 		return unless ($options && $options eq "txt");
 	}
 	return 1;
@@ -623,6 +623,51 @@ sub data
 
 *signature = \*data;
 
+=head2 prettify() - alters the signature to look "nicer" as an email header
+
+  $signature->prettify;
+
+This method may alter the signature in a way that breaks signatures, so
+it should be done ONLY when the signature is being generated, BEFORE being
+fed to the canonicalization algorithm.
+
+=cut
+
+sub prettify
+{
+	my $self = shift;
+	$self->wrap(
+		Start => length($self->{prefix} || "DKIM-Signature:"),
+		Tags => {
+			b => "b64",
+			bh => "b64",
+			h => "list",
+			},
+		);
+}
+
+=head2 prettify_safe() - same as prettify() but only touches the b= part
+
+  $signature->prettify_safe;
+
+This method will not break the signature, but it only affects the b= part
+of the signature.
+
+=cut
+
+sub prettify_safe
+{
+	my $self = shift;
+	$self->wrap(
+		Start => length($self->{prefix} || "DKIM-Signature:"),
+		Tags => {
+			b => "b64",
+			},
+		PreserveNames => 1,
+		Default => "preserve", #preserves unknown tags
+		);
+}
+
 =head2 timestamp() - get or set the signature timestamp (t=) field
 
 Signature timestamp (default is undef, meaning unknown creation time).
@@ -664,7 +709,7 @@ Jason Long, E<lt>jlong@messiah.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Messiah College
+Copyright (C) 2006-2007 by Messiah College
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
