@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 
-# Copyright 2005 Messiah College. All rights reserved.
+# Copyright 2005-2007 Messiah College. All rights reserved.
 # Jason Long <jlong@messiah.edu>
 
 # Copyright (c) 2004 Anthony D. Urso. All rights reserved.
@@ -81,7 +81,7 @@ See Mail::DKIM::SignerPolicy for more information about policy objects.
 package Mail::DKIM::Signer;
 use base "Mail::DKIM::Common";
 use Carp;
-our $VERSION = '0.24';
+our $VERSION = '0.26';
 
 # PROPERTIES
 #
@@ -233,14 +233,6 @@ sub finish_header
 	}
 }
 
-sub headers
-{
-	my $self = shift;
-	croak "unexpected argument" if @_;
-	my @headers = @{$self->{header_field_names}};
-	return join(":", @headers);
-}
-
 sub finish_body
 {
 	my $self = shift;
@@ -254,6 +246,9 @@ sub finish_body
 		my $signb64 = $algorithm->sign($self->{private});
 		$algorithm->signature->data($signb64);
 
+		# insert linebreaks in signature data, if desired
+		$algorithm->signature->prettify_safe();
+
 		$self->{signature} = $algorithm->signature;
 		$self->{result} = "signed";
 	}
@@ -348,6 +343,58 @@ terminators (same as the SMTP protocol).
 
 =cut
 
+=head2 headers() - determine which headers to put in signature
+
+  my $headers = $dkim->headers;
+
+This is a string containing the names of the header fields that
+will be signed, separated by colons.
+
+=cut
+
+# these are headers that "should" be included in the signature,
+# according to the DKIM spec.
+my @DEFAULT_HEADERS = qw(From Sender Reply-To Subject Date
+	Message-ID To Cc MIME-Version
+	Content-Type Content-Transfer-Encoding Content-ID Content-Description
+	Resent-Date Resent-From Resent-Sender Resent-To Resent-cc
+	Resent-Message-ID
+	In-Reply-To References
+	List-Id List-Help List-Unsubscribe List-Subscribe
+	List-Post List-Owner List-Archive);
+
+sub headers
+{
+	my $self = shift;
+	croak "unexpected argument" if @_;
+
+	# these are the header fields we found in the message we're signing
+	my @found_headers = @{$self->{header_field_names}};
+
+	# these are the headers we actually want to sign
+	my @wanted_headers = @DEFAULT_HEADERS;
+	if ($self->{Headers})
+	{
+		push @wanted_headers, split /:/, $self->{Headers};
+	}
+
+	my @headers =
+		grep { my $a = $_;
+			scalar grep { lc($a) eq lc($_) } @wanted_headers }
+		@found_headers;
+	return join(":", @headers);
+}
+
+# return nonzero if this is header we should sign
+sub want_header
+{
+	my $self = shift;
+	my ($header_name) = @_;
+
+	#TODO- provide a way for user to specify which headers to sign
+	return scalar grep { lc($_) eq lc($header_name) } @DEFAULT_HEADERS;
+}
+
 =head2 method() - get or set the selected canonicalization method
 
   $alg = $dkim->method;
@@ -493,7 +540,7 @@ Jason Long, E<lt>jlong@messiah.eduE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2006 by Messiah College
+Copyright (C) 2006-2007 by Messiah College
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
